summaryrefslogtreecommitdiff
path: root/src/build_post.php
diff options
context:
space:
mode:
Diffstat (limited to 'src/build_post.php')
-rw-r--r--src/build_post.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/build_post.php b/src/build_post.php
index 98f6dc7..aa0cbf6 100644
--- a/src/build_post.php
+++ b/src/build_post.php
@@ -6,8 +6,9 @@ function build_post_subject($listtag, $forumtag, $subject) {
'|' . preg_quote($forumtag, '/') . ')\\s*/';
$subj = preg_replace($tagpat, '', $subject);
- // strip leading sequences of Re-equivalents
- if (preg_match('/^(?:(?:RE|AW|SV|VS)(?:\\[\\d+\\])?:\\s*)+/i', $subj, $m)) {
+ // strip leading sequences of Re-equivalents and Edit
+ $re = '/^(?:(?:RE|AW|SV|VS|EDIT)(?:\\[\\d+\\])?:\\s*)+/i';
+ if (preg_match($re, $subj, $m)) {
$subj = substr($subj, strlen($m[0]));
}